==> elgg-1.10.1.zip: elgg-1.10.1/mod/reportedcontent/languages/gl.php <==
<?php
return array(

	'item:object:reported_content' => 'Elementos denunciados',
	'admin:administer_utilities:reportedcontent' => 'Contido denunciado',
	'reportedcontent' => 'Contido denunciado',
	'reportedcontent:this' => 'Denunciar',
	'reportedcontent:this:tooltip' => 'Denunciar a páxina ante un administrador',
	'reportedcontent:none' => 'Non hai contido denunciado',
	'reportedcontent:report' => 'Denunciar ante un administrador',
	'reportedcontent:deleted' => 'Eliminouse o contido denunciado.',
	'reportedcontent:notdeleted' => 'Non foi posíbel eliminar a denuncia.',
	'reportedcontent:delete' => 'Eliminar a denuncia',
	'reportedcontent:areyousure' => 'Está seguro de que quere eliminar?',
	'reportedcontent:archive' => 'Arquivar a denuncia',
	'reportedcontent:archived' => 'Arquivouse a denuncia.',
	'reportedcontent:visit' => 'Visitar o elemento denuciado',
	'reportedcontent:by' => 'Denuncia de',
	'reportedcontent:objecttitle' => 'Título',
	'reportedcontent:objecturl' => 'URL',
	'reportedcontent:reason' => 'Motivo da denuncia',
	'reportedcontent:description' => 'Por que está a denunciar isto?',
	'reportedcontent:address' => 'Lugar onde se atopa o elemento.',
	'reportedcontent:success' => 'Enviouse a denuncia ao administrador do sitio.',
	'reportedcontent:failing' => 'Non foi posíbel enviar o informe.',
	'reportedcontent:report' => 'Denunciar ante un administrador',
	'reportedcontent:instructions' => 'A denuncia enviarase aos administradores do sitio para que a revisen.',
	'reportedcontent:numbertodisplay' => 'Número de denuncias para mostrar',
	'reportedcontent:widget:description' => 'Mostrar o contido denunciado',
	'reportedcontent:user' => 'Denunciar o usuario',

	'reportedcontent:failed' => 'Non foi posíbel denunciar este contido.',
	'reportedcontent:notarchived' => 'Non foi posíbel arquivar a denuncia.',
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/reportedcontent/languages/gl.php <==
<?php
return array(

	'item:object:reported_content' => 'Elementos denunciados',
	'admin:administer_utilities:reportedcontent' => 'Contido denunciado',
	'reportedcontent' => 'Contido denunciado',
	'reportedcontent:this' => 'Denunciar',
	'reportedcontent:this:tooltip' => 'Denunciar a páxina ante un administrador',
	'reportedcontent:none' => 'Non hai contido denunciado',
	'reportedcontent:report' => 'Denunciar ante un administrador',
	'reportedcontent:deleted' => 'Eliminouse o contido denunciado.',
	'reportedcontent:notdeleted' => 'Non foi posíbel eliminar a denuncia.',
	'reportedcontent:delete' => 'Eliminar a denuncia',
	'reportedcontent:archive' => 'Arquivar a denuncia',
	'reportedcontent:archived' => 'Arquivouse a denuncia.',
	'reportedcontent:by' => 'Denuncia de',
	'reportedcontent:objecttitle' => 'Título',
	'reportedcontent:objecturl' => 'URL',
	'reportedcontent:reason' => 'Motivo da denuncia',
	'reportedcontent:description' => 'Por que está a denunciar isto?',
	'reportedcontent:address' => 'Lugar onde se atopa o elemento.',
	'reportedcontent:success' => 'Enviouse a denuncia ao administrador do sitio.',
	'reportedcontent:refresh' => 'Actualizar a lista',
	'reportedcontent:report' => 'Denunciar ante un administrador',
	'reportedcontent:instructions' => 'A denuncia enviarase aos administradores do sitio para que a revisen.',
	'reportedcontent:numbertodisplay' => 'Número de denuncias para mostrar',
	'reportedcontent:user' => 'Denunciar o usuario',

	'reportedcontent:failed' => 'Non foi posíbel denunciar este contido.',
	'reportedcontent:notarchived' => 'Non foi posíbel arquivar a denuncia.',
	
	'widgets:reportedcontent:name' => 'Reported content',
	'widgets:reportedcontent:description' => 'Display reported content',
);
